@@ -11,6 +11,7 @@ module Codec.Archive
     , entriesToFile7Zip
     , entriesToFileCpio
     , entriesToFileXar
+    , entriesToFileShar
     , entriesToBS
     , entriesToBS7zip
     , entriesToBSzip
@@ -19,6 +20,7 @@ module Codec.Archive
     , entriesToBSL7zip
     , entriesToBSLCpio
     , entriesToBSLXar
+    , entriesToBSLShar
     , readArchiveFile
     , readArchiveBS
     , readArchiveBSL
@@ -27,13 +29,16 @@ module Codec.Archive
     , packFiles7zip
     , packFilesCpio
     , packFilesXar
+    , packFilesShar
     , packToFile
     , packToFileZip
     , packToFile7Zip
     , packToFileCpio
     , packToFileXar
+    , packToFileShar
     -- * Concrete (Haskell) types
     , ArchiveResult (..)
+    , ArchiveEntryDigest (..)
     , Entry (..)
     , Symlink (..)
     , EntryContent (..)
@@ -44,15 +49,16 @@ module Codec.Archive
     -- * Archive monad
     , ArchiveM
     , runArchiveM
+    , throwArchiveM
     -- * Permissions helpers
     , standardPermissions
     , executablePermissions
     ) where
 
-import           Codec.Archive.Monad
-import           Codec.Archive.Pack
-import           Codec.Archive.Pack.Lazy
+import           Codec.Archive.Internal.Monad
+import           Codec.Archive.Internal.Pack
+import           Codec.Archive.Internal.Pack.Lazy
+import           Codec.Archive.Internal.Unpack
+import           Codec.Archive.Internal.Unpack.Lazy
 import           Codec.Archive.Permissions
 import           Codec.Archive.Types
-import           Codec.Archive.Unpack
-import           Codec.Archive.Unpack.Lazy
